![](./.logos/header.png)

# Core Cosmology Library: Precision Cosmological Predictions for LSST

*David Alonso, Nora Elisa Chisari, Elizabeth Krause, C. Danielle Leonard, Sukhdeep Singh, Antonio Villarreal, Michal Vrastil, Joe Zuntz, TJP Working Group*

An overview of the core cosmology library, providing routines for cosmological predictions with validated numerical accuracy.

This Note was generated on: |date|


## Introduction

Write your introduction here!

## Method

Write about your methods here! Or change the sections to whatever you want!

## Results

Write about your results here! Or don't!

## Conclusions

Write about your conclusions here. You have drawn some, right?





# Appendix: LSST DESC Notes `Markdown` Reference

You can delete all of this whenever you're ready.

## Introduction

This is a template [`Markdown`](https://github.com/adam-p/Markdown-here/wiki/Markdown-Cheatsheet) LSST DESC Note, for you to adapt for
your own work.

## Sectioning

As you can see above, your content can easily be divided into sections.
You can also make subsections, as follows.

### A Subsection

You can even have subsubsections, like this:

#### A Subsubsection

See? This is a subsubsection.

#### Another Subsubsection

And so is this.

### Another Subsection

And so on.

Math
----

You can typeset mathematics using latex commands like this:

$$\langle f(k) \rangle = \frac{ \sum_{t=0}^{N}f(t,k) }{N}$$

While this does not render on GitHub, it should get [picked up by
Sphinx](http://www.sphinx-doc.org/en/stable/ext/math.html) later and
will be available for you to re-use in future latex documents.

Code
----

You can show code in blocks like this:

```python
print "Hello World"
```

or this:

```bash
echo "Hello World"
```

Inline mentions of code `objects` can be made using pairs of backquotes.

## Figures

To add figures, add the required image file (PNG, SVG or JPG preferred)
to the `figures` subdirectory in your Note's folder. Here's an example:

![](./figures/example.jpg)
This is the figure caption: above we have the LSST DESC logo, in JPG format.

And then the text continues. Note that GitHub ignores the image sizing
commands when presenting [`Markdown`](https://github.com/adam-p/Markdown-here/wiki/Markdown-Cheatsheet) format documents; Sphinx might not.

## Tables

Tables can be fiddly in [`Markdown`](https://github.com/adam-p/Markdown-here/wiki/Markdown-Cheatsheet). A good place to start is an online table generator like [this one](http://www.tablesgenerator.com/Markdown_tables). Then, you'll need some patience. For more on table formatting, see the [`Markdown` cheat-sheet](https://github.com/adam-p/Markdown-here/wiki/Markdown-Cheatsheet#tables).

|   A   |   B   |      C         |  D  |
|:-----:|:-----:|:--------------:|:---:|
| (deg) | (kpc) | ($M_{\odot}$)  |     |
|  0.4  |  3.4  |  $10^{12.2}$   | R,S |
|  9.6  |  8.2  |  $10^{10.4}$   |  S  |


## References

You can cite papers (or anything else) by providing hyperlinks. For
example, you might have been impressed by the DESC White Paper [(LSST
Dark Energy Science Collaboration
2012)](http://arxiv.org/abs/1211.0310). It should be possible to convert
these links to latex citations automatically later.

## Further Resources

For a guide to writing `Markdown` documents, check out this [useful little cheatsheet](https://github.com/adam-p/Markdown-here/wiki/Markdown-Cheatsheet).
